# Encodings for adding incremental constraints

::: src/coomsuite/encodings/multi/inc-constraint.lp
    handler: asp
    options:
        encodings: true

## Encodings for incremental boolean constraints
::: src/coomsuite/encodings/multi/inc-function.lp
    handler: asp
    options:
        encodings: true

::: src/coomsuite/encodings/multi/inc-unary.lp
    handler: asp
    options:
        encodings: true

::: src/coomsuite/encodings/multi/inc-binary.lp
    handler: asp
    options:
        encodings: true
